from django.urls import reverse
from rest_framework import viewsets
from rest_framework import permissions
from rest_framework import status
from rest_framework.response import Response

from uhepp_vault.models import Plot
from .serializers import PlotSerializer

class CreateModelMixin:
    """Create a model instance with Location header"""
    def create(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        obj = self.perform_create(serializer)
        headers = self.get_success_headers(obj)
        return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)

    def perform_create(self, serializer):
        obj = serializer.save()
        return obj

    def get_success_headers(self, obj):
        api_url = reverse('uhepp_api:plot-detail', args=[obj.uuid])
        api_url = self.request.build_absolute_uri(api_url)

        ui_url = reverse('uhepp_vault:plot-detail', args=[obj.uuid])
        ui_url = self.request.build_absolute_uri(ui_url)
        return {
            'Location': api_url,
            'Link': f'<{ui_url}>; rel="ui"',
            'X-Resource-UUID': obj.uuid,
        }
    
class PlotSet(CreateModelMixin,
                   viewsets.mixins.RetrieveModelMixin,
                   viewsets.GenericViewSet):
    queryset = Plot.objects.all()
    serializer_class = PlotSerializer
    permission_classes = [permissions.IsAuthenticated]
