
from django.conf import settings
from django.contrib.auth.models import User
from mozilla_django_oidc.auth import OIDCAuthenticationBackend
from .models import Profile

class UHeppOIDCAB(OIDCAuthenticationBackend):

    PROJECTS = ["atlas"]

    def get_userinfo(self, access_token, id_token, payload):
        """Return user details dictionary. The user details are extracted from
        the id_token's payload. The userinfo endpoint is not contacted"""
        return payload

    def filter_users_by_claims(self, claims):
        upn = claims.get('cern_upn')
        if not upn:
            return self.UserModel.objects.none()

        try:
            profile = Profile.objects.get(cern_upn=upn)
            return [profile.user]

        except Profile.DoesNotExist:
            return self.UserModel.objects.none()

    def _claims_to_project(self, claims):
        app_name = settings.OIDC_APP_NAME
        roles = claims.get("resource_access", {}).get(app_name, {}).get("roles", [])
        projects = [project for project in self.PROJECTS if project in roles]
        return ";".join(projects)

    def create_user(self, claims):
        username = "ch.cern." + claims["cern_upn"]
        user = User.objects.create(username=username,
                                   first_name=claims.get('given_name', ''),
                                   last_name=claims.get('family_name', ''),
                                   email=claims.get('email', ''))

        profile = Profile.objects.create(user=user,
                                         project=self._claims_to_project(claims),
                                         cern_upn=claims['cern_upn'],
                                         cern_uid=claims.get('cern_uid'),
                                         cern_person_id=claims.get('cern_person_id'),
                                         home_institute=claims.get('home_institute'))
        return user

    def update_user(self, user, claims):
        user.first_name = claims.get('given_name', '')
        user.last_name = claims.get('family_name', '')
        user.email = claims.get('email', '')

        user.profile.uid = claims.get('cern_uid')
        user.profile.cern_person_id = claims.get('cern_person_id')
        user.profile.home_institute = claims.get('home_institute')
        user.profile.project=self._claims_to_project(claims)
        user.profile.save()
        user.save()

        return user
