from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import gettext_lazy as _
from uhepp_api.models import Token
import uuid

class Plot(models.Model):
    """Database record of a uhepp compliant plot"""
    uuid = models.UUIDField(primary_key=True, default=uuid.uuid4)
    data = models.JSONField()

    def __str__(self):
        metadata = self.data.get("metadata", {})
        return metadata.get("filename", self.uuid)

class Profile(models.Model):
    """Use profile"""
    user = models.OneToOneField(User,
                                on_delete=models.CASCADE,
                                primary_key=True)
    cern_upn = models.CharField(_("User Principal Name"), max_length=100,
                                  unique=True)

    project = models.CharField(_("Project"), max_length=32, null=True,
                               blank=True)

    cern_uid = models.IntegerField(_("CERN User ID"), null=True, blank=True)
    home_institute = models.CharField(_("Home Institute"), max_length=100,
                                      null=True, blank=True)
    cern_person_id = models.IntegerField(_("CERN Person ID"), null=True,
                                          blank=True)



    def __str__(self):
        return self.cern_upn
