from django.shortcuts import render
from django.views import generic
from django.http import JsonResponse, HttpResponseRedirect
from django.urls import reverse
from django.shortcuts import get_object_or_404
from django.contrib.auth.decorators import login_required
from uhepp_api.models import Token

from .models import Plot
from .forms import TokenForm

class PlotIndex(generic.ListView):
    template_name = 'uhepp_vault/plots.html'
    context_object_name = 'plots'

    def get_queryset(self):
        """Return all plots in the db"""
        return Plot.objects.all()

class PlotDetail(generic.DetailView):
    model = Plot
    template_name = 'uhepp_vault/plot.html'
    context_object_name = 'plot'

def plot_detail_json(request, uuid):
    plot = get_object_or_404(Plot, pk=uuid)
    return JsonResponse(plot.data)

def home(request):
    plot_count = Plot.objects.count()
    context = dict(plot_count=plot_count)
    return render(request, "uhepp_vault/home.html", context=context)

@login_required
def token_index(request):
    if request.method == "POST":
        form = TokenForm(request.POST)
        if form.is_valid():
            form_data = form.clean()
            new_token = Token.objects.create(user=request.user,
                                             description=form_data["description"],
                                             expires=form_data["expires"])
                                                      
            return HttpResponseRedirect(request.get_full_path())
    else:
        form = TokenForm()

    token_list = Token.objects.filter(user=request.user)

    context = {
        'user': request.user,
        'tokens': token_list,
        'token_form': form,
    }

    return render(request, "uhepp_vault/token.html", context=context)
    
@login_required
def account(request):

    context = {
        'user': request.user,
    }

    return render(request, "uhepp_vault/account.html", context=context)
    
